@@ -85,7 +85,7 @@ if [ "x$JKJNIEXT" = "x" ]; then
     echo ""
     echo "Unknown Git tag/branch"
     echo "Use:"
-    echo "  --ver=<tag>|1.1.x|master|."
+    echo "  --ver=<tag>|1.1.x|1.2.x|main|."
     echo ""
     exit 1
 fi
@@ -133,37 +133,50 @@ else
     exit 1
 fi
 
-if [ "x$JKJNIEXT" = "xmaster" ]; then
-    JKJNIHASH=`git rev-parse --short origin/master`
+if [ "x$JKJNIEXT" = "xmain" ]; then
+    JKJNIHASH=`git ls-remote $GITBASE refs/heads/main | awk '{print $1}'`
+    JKJNIVER="$JKJNIEXT-$JKJNIHASH"
+elif [ "x$JKJNIEXT" = "x1.2.x" ]; then
+    JKJNIHASH=`git ls-remote $GITBASE refs/heads/1.2.x | awk '{print $1}'`
     JKJNIVER="$JKJNIEXT-$JKJNIHASH"
 elif [ "x$JKJNIEXT" = "x1.1.x" ]; then
-    JKJNIHASH=`git rev-parse --short origin/1.1.x`
+    JKJNIHASH=`git ls-remote $GITBASE refs/heads/1.1.x | awk '{print $1}'`
     JKJNIVER="$JKJNIEXT-$JKJNIHASH"
 elif [ "x$JKJNIEXT" = "x." ]; then
     JKJNIHASH=`git rev-parse --short HEAD`
     JKJNIVER="HEAD-$JKJNIHASH"
 else
-    JKJNIHASH=`git rev-parse --short refs/tags/$JKJNIEXT`
+    JKJNIHASH=`git ls-remote $GITBASE refs/tags/$JKJNIEXT | awk '{print $1}'`
     JKJNIVER="$JKJNIEXT"
     JKJNIREL=1
 fi
 echo "Using GIT repo       : \`${GITBASE}\`"
 echo "Using version        : \`${JKJNIVER}\`"
 
-# Checking for recentness of git subtree
-git checkout ${JKJNIHASH}
-if [ ! -d .git/refs/remotes/9.0.x ]; then
-    git remote add -f 9.0.x ${TCJAVA_GITBASE}
+if [ ! -d .git ]; then
+    rm -rf tmp-clone
+    git clone --no-checkout $GITBASE tmp-clone
+    mv tmp-clone/.git .
+    rm -rf tmp-clone
+    # Checking for recentness of git subtree
+    git checkout --force ${JKJNIHASH}
+else
+    # Checking for recentness of git subtree
+    git checkout ${JKJNIHASH}
 fi
-git remote update 9.0.x
-diffcount=$(git diff HEAD remotes/9.0.x/master java/org/apache/tomcat/jni | wc -l)
+
+if [ ! -d .git/refs/remotes/tcjava ]; then
+    git remote add -f tcjava ${TCJAVA_GITBASE}
+fi
+git remote update tcjava
+diffcount=`git diff HEAD remotes/tcjava/main java/org/apache/tomcat/jni | wc -l`
 
 if [ $diffcount -ne 0 ]; then
     echo "WARNING: git subtree is not up to date with"
     echo "         $TCJAVA_GITBASE"
     echo "         Either correct now by running"
     echo "         'git rm -rf java/org/apache/tomcat/jni'"
-    echo "         'git read-tree --prefix=java/org/apache/tomcat/jni/ -u 9.0.x/master:java/org/apache/tomcat/jni'"
+    echo "         'git read-tree --prefix=java/org/apache/tomcat/jni/ -u tcjava/main:java/org/apache/tomcat/jni'"
     echo "         'git commit'"
     echo "         or run this script with -f (force)"
     if [ "X$JKJNIFORCE" = "X1" ]
@@ -272,7 +285,7 @@ cp ${JKJNIDIST}/CHANGELOG.txt ${JKWINDIST}
 
 mv ${JKWINDIST}/build/docs ${JKWINDIST}/docs
 rm -rf ${JKWINDIST}/build
-for i in LICENSE NOTICE README.txt TODO.txt
+for i in LICENSE NOTICE README.txt
 do
     $PERL ${JKWINDIST}/native/build/lineends.pl --cr ${JKWINDIST}/${i}
 done
