@@ -19,7 +19,6 @@
 
 #include "tcn.h"
 
-#ifdef HAVE_OPENSSL
 #include "apr_poll.h"
 #include "ssl_private.h"
 
@@ -329,14 +328,15 @@ int SSL_callback_SSL_verify(int ok, X509_STORE_CTX *ctx)
     con->pha_state = PHA_COMPLETE;
 #endif
 
-    if (verify == SSL_CVERIFY_UNSET || verify == SSL_CVERIFY_NONE) {
+    if (verify == SSL_CVERIFY_UNSET ||
+        verify == SSL_CVERIFY_NONE) {
         return 1;
     }
 
-    if (SSL_VERIFY_ERROR_IS_OPTIONAL(errnum) && (verify == SSL_CVERIFY_OPTIONAL_NO_CA)) {
+    if (SSL_VERIFY_ERROR_IS_OPTIONAL(errnum) &&
+        (verify == SSL_CVERIFY_OPTIONAL_NO_CA)) {
+        ok = 1;
         SSL_set_verify_result(ssl, X509_V_OK);
-        // Skip OCSP checks since the CA is optional
-        return 1;
     }
 
     /*
@@ -718,7 +718,7 @@ static char **decode_OCSP_url(ASN1_OCTET_STRING *os, apr_pool_t *p)
         return NULL;
     }
     if (parse_ASN1_Sequence(ocsp_urls, &response, &numofresponses, p) ||
-            numofresponses ==0) {
+    		numofresponses ==0) {
         response = NULL;
     }
     return response;
@@ -966,7 +966,7 @@ static OCSP_RESPONSE *get_ocsp_response(apr_pool_t *p, X509 *cert, X509 *issuer,
     int ok = 0;
     apr_socket_t *apr_sock = NULL;
     apr_pool_t *mp;
-#if OPENSSL_VERSION_NUMBER < 0x30000000L || defined(LIBRESSL_VERSION_NUMBER)
+#ifdef LIBRESSL_VERSION_NUMBER
     if (OCSP_parse_url(url, &hostname, &c_port, &path, &use_ssl) == 0)
 #else
     if (OSSL_HTTP_parse_url(url, &use_ssl, NULL, &hostname, &c_port, NULL, &path, NULL, NULL) == 0)
@@ -1100,4 +1100,3 @@ static int ssl_ocsp_request(X509 *cert, X509 *issuer, X509_STORE_CTX *ctx)
 }
 
 #endif /* HAVE_OCSP */
-#endif /* HAVE_OPENSSL  */
